import { Dispatch, SetStateAction, ReactNode } from 'react';
import GoTrue, { User as GoTrueUser, Settings as GoTrueSettings } from 'gotrue-js';
import { TokenParam } from './token';
declare type authChangeParam = (user?: User) => string | void;
export declare type Settings = GoTrueSettings;
export declare type User = GoTrueUser;
declare type Provider = 'bitbucket' | 'github' | 'gitlab' | 'google';
declare type MaybeUserPromise = Promise<User | undefined>;
export declare type ReactNetlifyIdentityAPI = {
    user: User | undefined;
    /** not meant for normal use! you should mostly use one of the other exported methods to update the user instance */
    setUser: Dispatch<SetStateAction<User | undefined>>;
    isConfirmedUser: boolean;
    isLoggedIn: boolean;
    signupUser: (email: string, password: string, data: Object) => MaybeUserPromise;
    loginUser: (email: string, password: string, remember?: boolean) => MaybeUserPromise;
    logoutUser: () => MaybeUserPromise;
    requestPasswordRecovery: (email: string) => Promise<void>;
    recoverAccount: (remember?: boolean) => MaybeUserPromise;
    updateUser: (fields: {
        data: object;
    }) => MaybeUserPromise;
    getFreshJWT: () => Promise<string>;
    authedFetch: {
        get: (endpoint: string, obj?: {}) => Promise<any>;
        post: (endpoint: string, obj?: {}) => Promise<any>;
        put: (endpoint: string, obj?: {}) => Promise<any>;
        delete: (endpoint: string, obj?: {}) => Promise<any>;
    };
    _goTrueInstance: GoTrue;
    _url: string;
    loginProvider: (provider: Provider) => void;
    acceptInviteExternalUrl: (provider: Provider) => string;
    settings: Settings;
    param: TokenParam;
};
export declare const useIdentityContext: () => ReactNetlifyIdentityAPI;
/** most people should use this provider directly */
export declare function IdentityContextProvider({ url, children, onAuthChange, }: {
    url: string;
    children: ReactNode;
    onAuthChange?: authChangeParam;
}): JSX.Element;
/** some people may want to use this as a hook and bring their own contexts */
export declare function useNetlifyIdentity(url: string, onAuthChange?: authChangeParam, enableRunRoutes?: boolean): ReactNetlifyIdentityAPI;
export {};
